#include <iostream>
#include <map>
#include <vector>
#include <set>
#include <cstdio>

using namespace std;

typedef int weightType;

class Network
{
public:
	Network();
	~Network();
	void init();
	void addNode(const int &new_id, const weightType &new_weight);
	void addArc(const int &new_id1, const int &new_id2, const weightType &new_weight);
	int getNode(const int &nodeID);
	int getArc(const int &nodeID1, const int &nodeID2);
	bool hasNode(const int &nodeID);
	bool hasArc(const int &nodeID1, const int &nodeID2);
	void removeNode(const int &nodeID);
	void removeArc(const int &nodeID1, const int &nodeID2);
	void getP(const vector<int> path);
	
protected:
	map<int, map<int, weightType> > arc;
	map<int, weightType> node;
};

class StarRingNetwork : public Network
{
public:
	bool addArc(const int &new_id1, const int &new_id2, const weightType &new_weight);
	void removeNode(const int &nodeID);
	void removeArc(const int &nodeID1, const int &nodeID2);
	void print();
	~StarRingNetwork();
	void init();
private:
	map<int, map<int, weightType> > arc_link;
};

bool StarRingNetwork::addArc(const int &new_id1, const int &new_id2, const weightType &new_weight)
{
	map<int, weightType>::iterator it;
	
	it = arc[new_id1].find(new_id2);
	if (it != arc[new_id1].end()){
		return false;
	}

	it = arc_link[new_id1].find(new_id2);
	if (it == arc_link[new_id1].end() && arc_link[new_id1].size() == 2)
		return false;
	it = arc_link[new_id2].find(new_id1);
	if (it == arc_link[new_id2].end() && arc_link[new_id2].size() == 2)
		return false;

	Network::addArc(new_id1, new_id2, new_weight);
	if (new_id1 != 1 && new_id2 != 1){
		arc_link[new_id1][new_id2] = 0;
		arc_link[new_id2][new_id1] = 0;
	}
	
	return true;
}

void StarRingNetwork::removeNode(const int &nodeID)
{
	map<int, map<int, weightType> >::iterator it;
	map<int, weightType> ::iterator itin;
	if(node.find(nodeID) != node.end())
		for ( it = arc_link.begin(); it != arc_link.end(); it++ ){
			itin = it->second.find(nodeID);
			if ( itin != it->second.end()){
				it->second.erase(itin);
			}
		it = arc_link.find(nodeID);
		arc_link.erase(it);
		Network::removeNode(nodeID);
	}
	cout << "end" << endl;
}

void StarRingNetwork::removeArc(const int &nodeID1, const int &nodeID2)
{
	map<int, map<int, weightType> >::iterator it;
	map<int, weightType> ::iterator itin;
	if(node.find(nodeID1) != node.end() && node.find(nodeID2) != node.end() && hasArc(nodeID1, nodeID2)){
		if (!hasArc(nodeID2, nodeID1)){
			arc_link[nodeID1].erase(nodeID2);
			arc_link[nodeID2].erase(nodeID1);
		}
		Network::removeArc(nodeID1, nodeID2);
	}
}

Network::Network()
{
}

Network::~Network()
{
	arc.clear();
	node.clear();
}

StarRingNetwork::~StarRingNetwork()
{
	arc.clear();
	node.clear();
	arc_link.clear();
}

void Network::init()
{
	arc.clear();
	node.clear();
}
void StarRingNetwork::init()
{
	Network::init();
	arc_link.clear();
}

void Network::addNode(const int &new_id, const weightType &new_weight)
{
	if(node.find(new_id) == node.end())
		node[new_id] = new_weight;
}
void Network::addArc(const int &new_id1, const int &new_id2, const weightType &new_weight)
{
	map<int, map<int, weightType> >::iterator it;
	it = arc.find(new_id1);
	if (it == arc.end())
	{
		arc[new_id1][new_id2] = new_weight;
		return;
	}
	else
	{
		if (it->second.find(new_id2) == it->second.end())
		{
			arc[new_id1][new_id2] = new_weight;
		}
	}
}
int Network::getNode(const int &nodeID)
{
	return node.find(nodeID)->second;
}

int Network::getArc(const int &nodeID1, const int &nodeID2)
{
	return arc[nodeID1][nodeID2];
}
bool Network::hasNode(const int &nodeID)
{
	if(node.find(nodeID) == node.end())
	{
		return false;
	}
	else
	{
		return true;
	}
}

bool Network::hasArc(const int &nodeID1, const int &nodeID2)
{
	map<int, weightType> oldValue;
	if (arc.count(nodeID1) > 0)
	{
		oldValue = arc.find(nodeID1)->second;
		if(oldValue.count(nodeID2) > 0)
		{
			return true;
		}
		else
		{
			return false;
		}		
	}

}
void Network::removeNode(const int &nodeID)
{
	map<int, map<int, weightType> >::iterator it;
	map<int, weightType>::iterator it2;
	if(node.find(nodeID) != node.end())
		node.erase(node.find(nodeID));

	if (arc.find(nodeID) != arc.end())
		arc.erase(arc.find(nodeID));
	cout<<"size:" << arc.size() << endl;
	for ( it = arc.begin(); it != arc.end(); it++ ){
		it2 = it->second.find(nodeID);

		if ( it2 != it->second.end()){
			cout<<"first"<<it->first<<" "<<it2->first <<endl;
			it->second.erase(it2);

		}cout<<"it:"<<it->first<<endl;
	}cout << "end 1"<<endl;
	return;
}

void Network::removeArc(const int &nodeID1, const int &nodeID2)
{
	map<int, weightType> oldValue;
	if (hasArc(nodeID1, nodeID2))
	{
		oldValue = arc.find(nodeID1)->second;
		oldValue.erase(nodeID2);
		if (oldValue.empty())
		{
			arc.erase(nodeID1);
		}
		else
		{
			arc[nodeID1] = oldValue;
		}
	}
}
void Network::getP(const vector<int> path)
{
	int sumLength = 0;
	int sumSupply = 0;

	// total_length_of_path 
	bool isEveryArcExist = false;

	for (int i = 0; i < path.size()-1; i++)
	{
		if (hasNode(path[i]) && hasNode(path[i+1]) && hasArc(path[i], path[i+1]) )
		{
			sumLength += getArc(path[i], path[i+1]);
			isEveryArcExist = true;
		}
		else
		{
			isEveryArcExist = false;
			break;
		}
	}	

	if (isEveryArcExist)
	{
		// sum_of_supply_quantities
		set<int> path_set;
		set<int>::iterator it;
		for (int i = 0; i < path.size(); i++)
		{
			path_set.insert(path[i]);
		}	
		for (it=path_set.begin(); it!=path_set.end(); ++it)
		{
    		sumSupply += getNode(*it);
		}
		cout << sumLength << " " << sumSupply << endl;
	}
	else
	{
		cout << "0" << endl;
	}
}

void StarRingNetwork::print()
{
	map<int, map<int, weightType> >::iterator it;
	map<int, weightType>::iterator it2;
	for ( it = arc.begin(); it != arc.end(); it++ ){
    	cout <<  it->first<<": ";
    	for (it2 = it->second.begin(); it2 != it->second.end(); it2++)
    		cout <<it2->first<<" ";
    	cout << endl;
    }
    /*
    for ( it = arc_link.begin(); it != arc_link.end(); it++ ){
    	cout <<  it->first<<": ";
    	for (it2 = it->second.begin(); it2 != it->second.end(); it2++)
    		cout <<it2->first<<" ";
    	cout << endl;
    }*/

	return;
}
int main()
{
	StarRingNetwork net;
	
	char task[6];
	string pre_task = "P";
	int id1 = 0, id2 = 0, weight = 0;
	char a;
	StarRingNetwork network;

	while (cin >> task)
	{
		if (task[0] == 'A' && task[1] == 'N')
		{
			if (pre_task == "P")
			{
				pre_task = "AN";
				network.init();	
			}
			cin >> id1 >> weight;
			network.addNode(id1, weight);
			
		}
		else if (task[0] == 'A' && task[1] == 'A')
		{
			// cin >> id1 >> id2 >> weight; // too slow
			scanf("%d %d %d", &id1,&id2,&weight);
			bool check = network.addArc(id1, id2, weight);
			//cout << "AA:" << check << endl;
		}
		else if (task[0] == 'R' && task[1] == 'N')
		{
			cin >> id1;
			network.removeNode(id1);
		}
		else if (task[0] == 'R' && task[1] == 'A')
		{
			cin >> id1 >> id2;
			network.removeArc(id1, id2);
		}
		else if (task[0] == 'P')
		{
			pre_task = "P";
			int length = 0;
			int nodeFrom = 0, nodeTo = 0;
			vector<int> path;


			while(true)
			{
				a = cin.get();
				if(a == '\n')
				{
					break;
				}
				else if (a == ' ')
				{

				}
				else
				{	
					cin.putback(a);
					cin >> id1;
					path.push_back(id1);
				}
			}
			// output result
			network.getP(path);

		}
	}
	network.print();
	return 0;
}